summaryrefslogtreecommitdiffstats
path: root/tdecore/tdecmdlineargs.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdecore/tdecmdlineargs.h')
-rw-r--r--tdecore/tdecmdlineargs.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/tdecore/tdecmdlineargs.h b/tdecore/tdecmdlineargs.h
index fe97fa09c..c494c206f 100644
--- a/tdecore/tdecmdlineargs.h
+++ b/tdecore/tdecmdlineargs.h
@@ -241,14 +241,14 @@ public:
* translation. Example: I18N_NOOP("KEdit")
* @param _description A short description of what your application is about.
* @param _version A version.
* @param noKApp Set this true to not add commandline options for
* TQApplication / TDEApplication
*
* @since 3.2
*/
static void init(int _argc, char **_argv, const char *_appname,
const char* programName, const char *_description,
- const char *_version, bool noKApp = false);
+ const char *_version, bool noTDEApp = false);
/**
* @deprecated
* You should convert any calls to this method to use the one
@@ -257,7 +257,7 @@ public:
*/
static void init(int _argc, char **_argv,
const char *_appname, const char *_description,
- const char *_version, bool noKApp = false) TDE_DEPRECATED;
+ const char *_version, bool noTDEApp = false) TDE_DEPRECATED;
/**
* Initialize class.
@@ -269,11 +269,11 @@ public:
* @param _argc As passed to @p main(...).
* @param _argv As passed to @p main(...).
* @param about A TDEAboutData object describing your program.
* @param noKApp Set this true to not add commandline options for
* TQApplication / TDEApplication
*/
static void init(int _argc, char **_argv,
- const TDEAboutData *about, bool noKApp = false);
+ const TDEAboutData *about, bool noTDEApp = false);
/**
* Initialize Class
@@ -241,14 +241,14 @@ public:
* @param _description A short description of what your application is about.
* @param _version A version.
- * @param noKApp Set this true to not add commandline options for
+ * @param noTDEApp Set this true to not add commandline options for
* TQApplication / TDEApplication
*
@@ -269,11 +269,11 @@ public:
* @param _argv As passed to @p main(...).
* @param about A TDEAboutData object describing your program.
- * @param noKApp Set this true to not add commandline options for
+ * @param noTDEApp Set this true to not add commandline options for
* TQApplication / TDEApplication
*/